@@ -22,12 +22,12 @@ class mNotes(object):
 
   __pretty_app_name__ = "mNotes"
   __app_name__ = "mNotes"
-  __version__ = "0.2.0"
+  __version__ = "0.2.1"
   __context__ = "net.khertan.mnotes"
 
   _glade_files = [
-    #'/usr/lib/mnotes/ui/mnotes.glade',
-    'ui/mnotes.glade',
+    '/usr/lib/mnotes/ui/mnotes.glade',
+    #'ui/mnotes.glade',
   ]
 
   def __init__(self,app,context):
